OC.L10N.register(
    "updatenotification",
    {
    "{version} is available. Get more information on how to update." : "Η έκδοση {version} είναι διαθέσιμη. Δείτε περισσότερες πληροφορίες για το πως να κάνετε την ενημέρωση.",
    "Channel updated" : "Ενημερωμένο κανάλι",
    "Web updater is disabled" : "Η ενημερώσεις μέσω ιστού έχουν απενεργοποιηθεί",
    "Update notifications" : "Ειδοποιήσεις ενημέρωσης",
    "The update server could not be reached since %d days to check for new updates." : "Ο διακομιστής ενημέρωσης δεν ήταν προσβάσιμος από %dημέρες για να ελέγξει για νέες ενημερώσεις. ",
    "Please check the Nextcloud and server log files for errors." : "Παρακαλούμε ελέγξτε για σφάλματα στα αρχεία ιστορικού του Nextcloud και του διακομιστή σας.",
    "Update to %1$s is available." : "Είναι διαθέσιμη η ενημέρωση σε %1$s.",
    "Update for {app} to version %s is available." : "Είναι διαθέσιμη η ενημέρωση της εφαρμογής {app} στην έκδοση %s",
    "Update notification" : "Ειδοποίηση ενημέρωσης",
    "Displays update notifications for Nextcloud and provides the SSO for the updater." : "Εμφανίζει ειδοποιήσεις ενημέρωσης για το Nextcloud και παρέχει το SSO για την εφαρμογή ενημέρωσης.",
    "Update" : "Ενημέρωση",
    "The version you are running is not maintained anymore. Please make sure to update to a supported version as soon as possible." : "Η έκδοση που εκτελείτε δεν διατηρείται πια. Βεβαιωθείτε ότι ενημερώσατε σε μια υποστηριζόμενη έκδοση το συντομότερο δυνατό.",
    "Apps missing compatible version" : "Εφαρμογές χωρίς συμβατή έκδοση",
    "View in store" : "Προβολή στο κέντρο εφαρμογών",
    "Apps with compatible version" : "Εφαρμογές με συμβατή έκδοση",
    "Open updater" : "Άνοιγμα εφαρμογής ενημέρωσης",
    "Download now" : "Λήψη τώρα",
    "What's new?" : "Τι νέο υπάρχει;",
    "View changelog" : "Εμφάνιση αλλαγών",
    "The update check is not yet finished. Please refresh the page." : "Ο έλεγχος ενημερώσεων δεν τελείωσε ακόμη. Παρακαλώ ανανεώστε την σελίδα.",
    "Your version is up to date." : "Έχετε την τελευταία έκδοση.",
    "A non-default update server is in use to be checked for updates:" : "Ένας μή-προεπιλεγμένος διακομιστής είναι σε χρήση για έλεγχο ενημερώσεων:",
    "You can always update to a newer version. But you can never downgrade to a more stable version." : "Μπορείτε πάντα να ενημερώσετε σε μια νεότερη έκδοση. Αλλά δεν μπορείτε ποτέ να υποβαθμίσετε σε μια πιο σταθερή έκδοση.",
    "Notify members of the following groups about available updates:" : "Να ενημερωθούν τα μέλη των παρακάτω ομάδων σχετικά με τις διαθέσιμες ενημερώσεις:",
    "Only notifications for app updates are available." : "Διατίθενται μόνο ειδοποιήσεις για ενημερώσεις εφαρμογών.",
    "The selected update channel makes dedicated notifications for the server obsolete." : "Το συγκεκριμένο κανάλι ενημέρωσης καθιστά παρωχημένες τις ειδοποιήσεις που προορίζονται για τον διακομιστή.",
    "The selected update channel does not support updates of the server." : "Το συγκεκριμένο κανάλι ενημέρωσης δεν υποστηρίζει ενημερώσεις διακομιστή.",
    "A new version is available: <strong>{newVersionString}</strong>" : "Μία νέα έκδοση είναι διαθέσιμη: <strong>{newVersionString}</strong>",
    "Checking apps for compatible versions" : "Έλεγχος εφαρμογών για συμβατές εκδόσεις",
    "Please make sure your config.php does not set <samp>appstoreenabled</samp> to false." : "Σιγουρευτείτε πως το config.php δεν έχει οριστεί σε ψευδήςψ<samp>ενεργοποίησηαγοράςεφαρμογών</samp>.",
    "Could not connect to the App Store or no updates have been returned at all. Search manually for updates or make sure your server has access to the internet and can connect to the App Store." : "Δεν ήταν δυνατή η σύνδεση στο App Store ή δε βρέθηκαν καθόλου ενημερώσεις. Αναζητήστε χειρωνακτικά ενημερώσεις ή βεβαιωθείτε ότι ο διακομιστής σας έχει πρόσβαση στο διαδίκτυο και μπορεί να συνδεθεί στο App Store.",
    "<strong>All</strong> apps have a compatible version for this Nextcloud version available." : "<strong>Όλες</strong> οι εφαρμογές έχουν διαθέσιμη μια συμβατή έκδοση για αυτήν την έκδοση Nextcloud.",
    "Enterprise" : "Επαγγελματιών",
    "For enterprise use. Provides always the latest patch level, but will not update to the next major release immediately. That update happens once Nextcloud GmbH has done additional hardening and testing for large-scale and mission-critical deployments. This channel is only available to customers and provides the Nextcloud Enterprise package." : "Για επαγγελματική χρήση. Παρέχει πάντα την τελευταία ενημέρωση, αλλά δεν θα ενημερωθεί αμέσως στην επόμενη μεγάλη έκδοση. Η ενημέρωση αυτή συμβαίνει μόλις η Nextcloud GmbH πραγματοποιήσει επιπλέον ελέγχους και δοκιμές για εφαρμογές μεγάλης κλίμακας και κρίσιμης σημασίας για την αποστολή. Αυτό το κανάλι είναι διαθέσιμο μόνο στους πελάτες και παρέχει το πακέτο Nextcloud για Επαγγελματίες.",
    "Stable" : "Σταθερός",
    "The most recent stable version. It is suited for regular use and will always update to the latest major version." : "Η πιο πρόσφατη σταθερή έκδοση. Είναι κατάλληλη για τακτική χρήση και πάντα θα ενημερώνεται με την τελευταία μεγάλη έκδοση.",
    "Beta" : "Δοκιμαστικό",
    "A pre-release version only for testing new features, not for production environments." : "Μια προηγούμενη έκδοση μόνο για τη δοκιμή νέων λειτουργιών, όχι για περιβάλλοντα παραγωγής.",
    "_<strong>%n</strong> app has no compatible version for this Nextcloud version available._::_<strong>%n</strong> apps have no compatible version for this Nextcloud version available._" : ["<strong>%n</strong> εφαρμογή δεν έχει διαθέσιμη συμβατή έκδοση για αυτήν την έκδοση Nextcloud.","<strong>%n</strong> εφαρμογές δεν έχουν διαθέσιμη συμβατή έκδοση για αυτήν την έκδοση Nextcloud."],
    "Please note that the web updater is not recommended with more than 100 users! Please use the command line updater instead!" : "Παρακαλούμε λάβετε υπόψη ότι ο web updater δεν συνιστάται για περισσότερους από 100 χρήστες! Παρακαλούμε χρησιμοποιήστε αντ' αυτού το πρόγραμμα ενημέρωσης γραμμής εντολών!",
    "Please use the command line updater to update." : "Παρακαλούμε κάντε ενημέρωση μέσω γραμμής εντολών.",
    "You can change the update channel below which also affects the apps management page. E.g. after switching to the beta channel, beta app updates will be offered to you in the apps management page." : "Μπορείτε να αλλάξετε το κανάλι ενημέρωσης παρακάτω, το οποίο επηρεάζει επίσης τη σελίδα διαχείρισης εφαρμογών. Π.χ. μετά την αλλαγή στο κανάλι beta, θα σας προσφέρονται ενημερώσεις εφαρμογών beta στη σελίδα διαχείρισης εφαρμογών.",
    "Update channel:" : "Ενημέρωση καναλιού:",
    "Note that after a new release the update only shows up after the first minor release or later. We roll out new versions spread out over time to our users and sometimes skip a version when issues are found. Learn more about updates and release channels at {link}" : "Σημειώστε ότι μετά από μια νέα έκδοση, η ενημέρωση εμφανίζεται μόνο μετά την πρώτη υποέκδοση ή αργότερα. Κυκλοφορούμε νέες εκδόσεις που διαμοιράζονται με την πάροδο του χρόνου στους χρήστες μας και μερικές φορές παραλείπουμε μια έκδοση όταν εντοπίζονται προβλήματα. Μάθετε περισσότερα σχετικά με τις ενημερώσεις και τα κανάλια κυκλοφορίας στη διεύθυνση {link}",
    "Checked on {lastCheckedDate}" : "Έγινε έλεγχος στις {lastCheckedDate}"
},
"nplurals=2; plural=(n != 1);");
